# Preprocessing `pp`

Preprocessing functions for seqlet extraction and motif similarity analysis.

```{eval-rst}
.. module:: tfmindi.pp
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    pp.extract_seqlets
    pp.calculate_motif_similarity
    pp.create_seqlet_adata
```
